=====
Usage
=====

Just run pep582 once and your interpreters site.py would be patched to work with __pypackages__

if you create __pypackages__ directorry inside your projects:

"pip install" would install there by default

to install elsewhere use -t/--target

modules would me imported from there first
